#include <iostream>
#include <queue>

#define NMAX 42

using namespace std;

/* Nombre de sommets  traiter */
int n;

/* Couplage */
int mateX[NMAX];
int mateY[NMAX];

/* Arbre hongrois */
int prec[NMAX];

/* Matrice des poids des artes */
int w[NMAX][NMAX];

/* Potentiels */
int lX[NMAX];
int lY[NMAX];

/* Liste d'adjacence dans le graphe d'galit */
int voisinsX[NMAX][NMAX];

/* Sommets de S et T */
bool S[NMAX];
bool T[NMAX];

/* Voisins libres des sommets de X */
int libre[NMAX];

/* Fonction de recherche d'un chemin amliorant pour augmenter le couplage
 * dans le graphe d'galit (elle ne recherche pas le couplage maximal).
 * Renvoie vrai si le chemin a pu tre augment. */
bool augmente_couplage_egalite()
{
	/* Recherche d'un chemin amliorant */

	queue <int> libresX;
       	/* On commence par les sommets libres de X */
	for(int i = 0; i < n; i++)
	{
		if(mateY[i] == -1)
		{
			libresX.push(i);
		}
	}

	/* On recherche des voisins libres des sommets de X et on rinitialise
	 * les ensembles S, T et l'arbre hongrois. */
	for(int i = 0; i < n; i++)
	{
		int j = 0; /* Compteur du nombre de voisins dans la liste
			      d'adjacence du sommet i */

		libre[i] = -1;
		prec[i] = -1;
		S[i] = false;
		T[i] = false;
	
		/* Itration sur les voisins dans Y du sommet i pour trouver
		 * un voisin libre. */	
		while(j < n && voisinsX[i][j] != -1 && libre[i] == -1)
		{
			if(mateX[voisinsX[i][j]] == -1)
			{
				/* Le voisin est libre */
				libre[i] = voisinsX[i][j];
			}

			j++;
		}
	}

	/* Parcours en largeur  partir des sommets de X et extension de
	 * l'arbre hongrois */	
	while(!libresX.empty())
	{
		int i = libresX.front();
		libresX.pop();

		S[i] = true; /* Marquer le sommet comme visit */

		/* On cherche un voisin de X */
		if(libre[i] >=0)
		{
			/* On tient un chemin amliorant !!! */
			int x = i;

			T[libre[i]] = true;

			/* Remonte de l'arbre hongrois pour transformer le
			 * chemin amliorant en couplage */
			while(x != -1)
			{
				int y = mateY[x];

				/* Dcoupler x et mateY[x] */
				mateX[y] = -1;
				
				/* Coupler x et libre[x] */
				mateX[libre[x]] = x;
				mateY[x] = libre[x];
				libre[x] = y;

				/* Passer au sommet suivant du chemin */
				x = prec[x];
			}
			return true;
		}
		
		/* i n'a pas de voisin libre, on tend l'arbre hongrois */
		for(int j = 0; j < n && voisinsX[i][j] >= 0; j++)
		{
			int z = mateX[voisinsX[i][j]]; /* Sommet de X coupl
							  au voisin de i */

			/* Si z n'a pas encore t vist, on accroche l'arbre
			 * partant de z et on met z en file pour continuer
			 *  l'tendre par la suite. */
			if(prec[z] == -1)
			{
				libresX.push(z);
				prec[z] = i;
				T[voisinsX[i][j]] = true;
			}
		}
	}
	return false;
}

/* On peut tenter de mettre ici un algorithme glouton pour partir d'un peu
 * mieux que le couplage vide. Mais en algorithmique effective, le problme
 * passera probablement le juge sans cela, et on perd du temps  dboguer en
 * plus un glouton... ;-) */
void couplage_initial_egalite()
{
}


/* Recre le graphe d'galit quand on vient de modifier les potentiels */
void maj_graphe_egalite()
{
	for(int i = 0; i < n; i++)
	{
		int vx = 0; /* Nombre de voisins dj ajouts au sommet i */

		for(int j = 0; j < n; j++)
		{
			if(w[i][j] == lX[i] + lY[j])
			{
				voisinsX[i][vx] = j;
				vx++;
			}
		}

		/* Rinitialisation au passage des partitions de X et Y, qui
		 * n'ont plus vraiment de sens quand on modifie le graphe. */
		S[i] = T[i] = false;
	}
}

/* Calcul du nombre de sommets appareills : en y rflchissant un peu on
 * pourrait probablement inclure ce comptage dans le calcul du couplage, mais
 * cela serait plus long  dvelopper. */
int sommets_couples()
{
	int res = 0;
	for(int i = 0; i < n; i++)
	{
		if(mateX[i] != -1)
		{
			res++;
		}
	}
	return res;
}

/* Calcul du couplage de poids maximum, en utilisant les fonctions
 *  prcdentes. */
void couplage_poids_max()
{
	maj_graphe_egalite();
	couplage_initial_egalite();

	while(sommets_couples() != n)
	{
		/* On augmente du plus possible le graphe d'galit */
		while(augmente_couplage_egalite()) {}

		/* On joue avec les potentiels */
		int delta = -1;

		/* delta = min(lX[i] + lY[j] - w[i][j]) pour i dans S et j dans
		 * le complmentaire de T */
		for(int i = 0; i < n; i++)
		{
			if(!S[i])
			{
				continue;
			}

			for(int j = 0; j < n; j++)
			{
				if(T[j])
				{
					continue;
				}
				
				int d = lX[i] + lY[j] - w[i][j];
				if(d < delta || delta == -1)
				{
					delta = d;
				}
			}
		}

		/* Mise  jour des potentiels de S et T */
		for(int i = 0; i < n; i++)
		{
			if(S[i])
			{
				lX[i] -= delta;
				lY[mateY[i]] += delta;
			}
		}

		/* On met  jour le graphe d'galit */
		maj_graphe_egalite();
	}
}

int main()
{
	cin >> n;

	/* On lit des matrices carres : d'abord leur taille n, puis les
	 * n^2 coefficients donnant les poids des artes. On s'arte quand
	 * n est nul. */
	while(n > 0)
	{
		/* Rinitialisation des structures de donnes */
		for(int i = 0; i < n; i++)
		{
			/* On vide le couplage et l'arbre hongrois */
			mateX[i] = mateY[i] = prec[i] = -1;

			/* On annule les potentiels */
			lY[i] = 0;
			lX[i] = 0;

			/* On vide S */
			S[i] = false;
			T[i] = false;

			for(int j = 0; j < n; j++)
			{
				voisinsX[i][j] = -1;
			}
		}

		/* Lecture des poids */
		for(int i = 0; i < n; i++)
		{
			for(int j = 0; j < n; j++)
			{
				cin >> w[i][j];

				/* Premire affectation valide (et gloutonne)
				 * des potentiels */
				if(w[i][j] > lX[i])
				{
					lX[i] = w[i][j];
				}
			}
		}
		couplage_poids_max();

		/* Affichage du poids maximal du couplage */
		int poids = 0;
		for(int i = 0; i < n; i++)
		{
			if(mateY[i] >= 0)
			{
				poids += w[i][mateY[i]];
			}
		}

		cout << poids << endl;

		/* Passage  l'itration suivante */
		cin >> n;
	}
}
